Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(475)

Unified Diff: test/get/hosted/stay_locked_test.dart

Issue 2377063002: Make "--no-packages-dir" the default. (Closed)
Patch Set: Revise again. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: test/get/hosted/stay_locked_test.dart
diff --git a/test/get/hosted/stay_locked_test.dart b/test/get/hosted/stay_locked_test.dart
index a1f47ba09a938be20320d757744c826742374b6a..92e60c82e3a50acd9f115f1c6f605d6adfac97c6 100644
--- a/test/get/hosted/stay_locked_test.dart
+++ b/test/get/hosted/stay_locked_test.dart
@@ -10,7 +10,7 @@ import '../../descriptor.dart' as d;
import '../../test_pub.dart';
main() {
- integration('keeps a pub server package locked to the version in the '
+ integration('keeps a hosted package locked to the version in the '
'lockfile', () {
servePackages((builder) => builder.serve("foo", "1.0.0"));
@@ -19,10 +19,10 @@ main() {
// This should lock the foo dependency to version 1.0.0.
pubGet();
- d.packagesDir({"foo": "1.0.0"}).validate();
+ d.appPackagesFile({"foo": "1.0.0"}).validate();
- // Delete the packages path to simulate a new checkout of the application.
- schedule(() => deleteEntry(path.join(sandboxDir, packagesPath)));
+ // Delete the .packages file to simulate a new checkout of the application.
+ schedule(() => deleteEntry(path.join(sandboxDir, packagesFilePath)));
// Start serving a newer package as well.
globalPackageServer.add((builder) => builder.serve("foo", "1.0.1"));
@@ -30,6 +30,6 @@ main() {
// This shouldn't upgrade the foo dependency due to the lockfile.
pubGet();
- d.packagesDir({"foo": "1.0.0"}).validate();
+ d.appPackagesFile({"foo": "1.0.0"}).validate();
});
}
« no previous file with comments | « test/get/hosted/stay_locked_if_new_is_satisfied_test.dart ('k') | test/get/hosted/unlock_if_incompatible_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698